#
# spec file for package python-uncertainties
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-uncertainties
Version:        3.1.7
Release:        2.1
Summary:        Uncertainties on the Quantities Involved (aka "Error Propagation")
License:        BSD-3-Clause
URL:            https://github.com/lebigot/uncertainties/
Source:         https://files.pythonhosted.org/packages/source/u/uncertainties/uncertainties-%{version}.tar.gz
Patch0:         remove-future-requirement.patch
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testsuite}
BuildRequires:  %{python_module tools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if 0%{?suse_version}
Recommends:     python-numpy
%endif
%python_subpackages

%description
"uncertainties" allows calculations such as (2±0.1)*2 = 4±0.2 to be
performed transparently. Much more complex mathematical expressions
involving numbers with uncertainties can also be evaluated directly.

%prep
%autosetup -p1 -n uncertainties-%{version}
sed -i -e '/^#!\//, 1d' uncertainties/1to2.py
sed -i -e '/^#!\//, 1d' uncertainties/lib1to2/test_1to2.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/uncertainties/
%{python_sitelib}/uncertainties-%{version}.dist-info

%changelog
* Thu Sep  7 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-future-requirement.patch, remove requirement for future
- Switch to pyproject and autosetup macros
* Thu Jun 23 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 3.1.7:
  * Emphasis added for automatic differentiation
  * Made the automatic differentiation capabilities clearer
* Thu Jul 22 2021 Arun Persaud <arun@gmx.de>
- update to version 3.1.6:
  * the pretty-print and LaTeX format can now be customized.
* Fri Feb 19 2021 Ben Greiner <code@bnavigator.de>
- Don't install and test numpy for python36. With NumPy 1.20, TW
  no longer provides a python36-numpy
* Sat Jan  9 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 3.1.5:
  * added a “p” formatting option, that makes sure that there are
    always parentheses around the … ± … part of printed numbers.
* Mon Jun 29 2020 pgajdos@suse.com
- switch from nosetests to pytest
* Wed Jun 24 2020 Todd R <toddrme2178@gmail.com>
- Update to 3.1.4
  * There is now a single code base for Python 2 and Python 3.
* Fri Aug 16 2019 Todd R <toddrme2178@gmail.com>
- Update to 3.1.2
  * Starting with NumPy 1.17, numpy.linalg.pinv has a None
  __defaults__ attribute, for which the code made no provision.
  This is fixed.
- Remove upstream-included patches:
  fix_raw_strings.patch
  fix_numpy_1_17.patch
* Wed Jul 31 2019 Todd R <toddrme2178@gmail.com>
- Add fix_raw_strings.patch
  Fix raw string escaping
  From: gh#lebigot/uncertainties#98
- Add fix_numpy_1_17.patch
  Fix building for numpy 1.17
  See: gh#lebigot/uncertainties#89
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.1:
  * No upstream changelog provided
* Tue Oct 30 2018 Arun Persaud <arun@gmx.de>
- update to version 3.0.3:
  * The deprecation warning raised by inspect.getargspec() in recent
    versions of Python 3 is now gone.
* Thu Sep  6 2018 Jan Engelhardt <jengelh@inai.de>
- Trim non-RPM markup from description. Ensure neutrality of
  description.
* Wed Sep  5 2018 arun@gmx.de
- specfile:
  * update copyright year
  * remove devel from noarch
- update to version 3.0.2:
  * This update contains only documentation updates (and new or
    updated code comments). Added explicit information on NaN
    handling.
* Thu Jul  6 2017 tbechtold@suse.com
- update to 3.0.1:
  See more details at
  https://pypi.python.org/pypi/uncertainties#version-history
- convert to singlespec
* Wed Apr 20 2016 tbechtold@suse.com
- Use tarball from pypi
* Thu Jul 16 2015 seife+obs@b1-systems.com
- fix build on non-SUSE distros whose rpm does not know Recommends:
* Thu May  8 2014 toddrme2178@gmail.com
- Updated to release 2.4.6
  See more details at
  https://pypi.python.org/pypi/uncertainties#version-history
* Sat Jan 18 2014 toms@opensuse.org
- Updated to release 2.4.4
  See more details at
  https://pypi.python.org/pypi/uncertainties#version-history
- Refreshed spec file
* Thu Mar 11 2010 toms@suse.de
- Initial package release 1.4.5
